@@ -38,6 +38,7 @@ static gboolean  initialized;
 static FILE     *fd;
 static gint      verbosity;
 static guint     log_handler_id;
+static gboolean  use_log_files;
 
 #if GLIB_CHECK_VERSION (2,31,0)
 static GMutex    mutex;
@@ -113,8 +114,18 @@ log_output (const gchar    *domain,
 	                          message);
 
 	if (G_UNLIKELY (fd == NULL)) {
-		g_fprintf (stderr, "%s\n", output);
-		fflush (stderr);
+		FILE *f;
+
+		if (log_level == G_LOG_LEVEL_WARNING ||
+		    log_level == G_LOG_LEVEL_CRITICAL ||
+		    log_level == G_LOG_LEVEL_ERROR) {
+			f = stderr;
+		} else {
+			f = stdout;
+		}
+
+		g_fprintf (f, "%s\n", output);
+		fflush (f);
 	} else {
 		size += g_fprintf (fd, "%s\n", output);
 		fflush (fd);
@@ -135,7 +146,10 @@ tracker_log_handler (const gchar    *domain,
                      const gchar    *message,
                      gpointer        user_data)
 {
-	log_output (domain, log_level, message);
+	/* Unless enabled, we don't log to file by default */
+	if (use_log_files) {
+		log_output (domain, log_level, message);
+	}
 
 	/* Now show the message through stdout/stderr as usual */
 	g_log_default_handler (domain, log_level, message, user_data);
@@ -154,8 +168,7 @@ gboolean
 tracker_log_init (gint    this_verbosity,
                   gchar **used_filename)
 {
-	gchar *filename;
-	gchar *basename;
+	const gchar *env_use_log_files;
 	const gchar *env_verbosity;
 	GLogLevelFlags hide_levels = 0;
 
@@ -163,6 +176,19 @@ tracker_log_init (gint    this_verbosity,
 		return TRUE;
 	}
 
+	env_use_log_files = g_getenv ("TRACKER_USE_LOG_FILES");
+	if (env_use_log_files != NULL) {
+		/* When set we use:
+		 *   ~/.local/share/Tracker/
+		 * Otherwise, we either of the following:
+		 *   ~/.xsession-errors
+		 *   ~/.cache/gdm/session.log
+		 *   systemd journal
+		 * Depending on the system.
+		 */
+		use_log_files = TRUE;
+	}
+
 	env_verbosity = g_getenv ("TRACKER_VERBOSITY");
 	if (env_verbosity != NULL) {
 		this_verbosity = atoi (env_verbosity);
@@ -183,25 +209,40 @@ tracker_log_init (gint    this_verbosity,
 		g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
 	}
 
-	basename = g_strdup_printf ("%s.log", g_get_application_name ());
-	filename = g_build_filename (g_get_user_data_dir (),
-	                             "tracker",
-	                             basename,
-	                             NULL);
-	g_free (basename);
+	if (use_log_files) {
+		gchar *basename;
+		gchar *filename;
 
-	/* Open file */
-	fd = g_fopen (filename, "a");
-	if (!fd) {
-		const gchar *error_string;
+		basename = g_strdup_printf ("%s.log", g_get_application_name ());
+		filename = g_build_filename (g_get_user_data_dir (),
+		                             "tracker",
+		                             basename,
+		                             NULL);
+		g_free (basename);
 
-		error_string = g_strerror (errno);
-		g_fprintf (stderr,
-		           "Could not open log:'%s', %s\n",
-		           filename,
-		           error_string);
-		g_fprintf (stderr,
-		           "All logging will go to stderr\n");
+		/* Open file */
+		fd = g_fopen (filename, "a");
+		if (!fd) {
+			const gchar *error_string;
+
+			error_string = g_strerror (errno);
+			g_fprintf (stderr,
+			           "Could not open log:'%s', %s\n",
+			           filename,
+			           error_string);
+			g_fprintf (stderr,
+			           "All logging will go to stderr\n");
+
+			use_log_files = TRUE;
+		}
+
+		if (used_filename) {
+			*used_filename = filename;
+		} else {
+			g_free (filename);
+		}
+	} else {
+		*used_filename = NULL;
 	}
 
 	verbosity = CLAMP (this_verbosity, 0, 3);
@@ -248,16 +289,10 @@ tracker_log_init (gint    this_verbosity,
 	/* Set log handler function for the rest */
 	g_log_set_default_handler (tracker_log_handler, NULL);
 
-	if (used_filename) {
-		*used_filename = filename;
-	} else {
-		g_free (filename);
-	}
-
 	initialized = TRUE;
 
 	/* log binary name and version */
-	g_message ("%s %s", g_get_application_name (), PACKAGE_VERSION);
+	g_message ("Starting %s %s", g_get_application_name (), PACKAGE_VERSION);
 
 	return TRUE;
 }
@@ -269,6 +304,8 @@ tracker_log_shutdown (void)
 		return;
 	}
 
+	g_message ("Stopping %s %s", g_get_application_name (), PACKAGE_VERSION);
+
 	/* Reset default log handler */
 	g_log_set_default_handler (g_log_default_handler, NULL);
 
@@ -277,7 +314,7 @@ tracker_log_shutdown (void)
 		log_handler_id = 0;
 	}
 
-	if (fd) {
+	if (use_log_files && fd != NULL) {
 		fclose (fd);
 	}
 
