@@ -859,7 +859,6 @@ main (gint argc, gchar *argv[])
 	gboolean store_available;
 
 	main_loop = NULL;
-	g_type_init ();
 
 	setlocale (LC_ALL, "");
 
@@ -899,8 +898,6 @@ main (gint argc, gchar *argv[])
 		return EXIT_SUCCESS;
 	}
 
-	g_print ("Initializing tracker-miner-fs...\n");
-
 	initialize_signal_handler ();
 
 	/* Initialize logging */
@@ -916,8 +913,10 @@ main (gint argc, gchar *argv[])
 
 	tracker_log_init (tracker_config_get_verbosity (config),
 	                  &log_filename);
-	g_print ("Starting log:\n  File:'%s'\n", log_filename);
-	g_free (log_filename);
+	if (log_filename) {
+		g_message ("Using log file:'%s'", log_filename);
+		g_free (log_filename);
+	}
 
 	sanity_check_option_values (config);
 
