@@ -34,6 +34,7 @@
 
 typedef struct {
 	const gchar *creator;
+	gchar *creator_uri;
 } MergeData;
 
 typedef struct {
@@ -68,16 +69,6 @@ typedef struct {
 	gchar *publisher;
 } VorbisData;
 
-static void extract_vorbis (const char            *uri,
-                            TrackerSparqlBuilder  *preupdate,
-                            TrackerSparqlBuilder  *metadata);
-
-static TrackerExtractData extract_data[] = {
-	{ "audio/x-vorbis+ogg", extract_vorbis },
-	{ "application/ogg", extract_vorbis },
-	{ NULL, NULL }
-};
-
 static gchar *
 ogg_get_comment (vorbis_comment *vc,
                  const gchar    *label)
@@ -95,11 +86,10 @@ ogg_get_comment (vorbis_comment *vc,
 	}
 }
 
-static void
-extract_vorbis (const char *uri,
-                TrackerSparqlBuilder *preupdate,
-                TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (TrackerExtractInfo *info)
 {
+	TrackerSparqlBuilder *preupdate, *metadata;
 	VorbisData vd = { 0 };
 	MergeData md = { 0 };
 	FILE *f;
@@ -109,19 +99,25 @@ extract_vorbis (const char *uri,
 	vorbis_info *vi;
 	unsigned int bitrate;
 	gint time;
+	GFile *file;
+	const gchar *graph;
 
-	filename = g_filename_from_uri (uri, NULL, NULL);
-
+	file = tracker_extract_info_get_file (info);
+	filename = g_file_get_path (file);
 	f = tracker_file_open (filename);
 	g_free (filename);
 
+	preupdate = tracker_extract_info_get_preupdate_builder (info);
+	metadata = tracker_extract_info_get_metadata_builder (info);
+	graph = tracker_extract_info_get_graph (info);
+
 	if (!f) {
-		return;
+		return FALSE;
 	}
 
 	if (ov_open (f, &vf, NULL, 0) < 0) {
 		tracker_file_close (f, FALSE);
-		return;
+		return FALSE;
 	}
 
 	tracker_sparql_builder_predicate (metadata, "a");
@@ -171,19 +167,27 @@ extract_vorbis (const char *uri,
 	md.creator = tracker_coalesce_strip (3, vd.artist, vd.album_artist, vd.performer);
 
 	if (md.creator) {
-		gchar *uri = tracker_sparql_escape_uri_printf ("urn:artist:%s", md.creator);
+		/* NOTE: This must be created before vd.album is evaluated */
+		md.creator_uri = tracker_sparql_escape_uri_printf ("urn:artist:%s", md.creator);
 
 		tracker_sparql_builder_insert_open (preupdate, NULL);
-		tracker_sparql_builder_subject_iri (preupdate, uri);
+		if (graph) {
+			tracker_sparql_builder_graph_open (preupdate, graph);
+		}
+
+		tracker_sparql_builder_subject_iri (preupdate, md.creator_uri);
 		tracker_sparql_builder_predicate (preupdate, "a");
 		tracker_sparql_builder_object (preupdate, "nmm:Artist");
 		tracker_sparql_builder_predicate (preupdate, "nmm:artistName");
 		tracker_sparql_builder_object_unvalidated (preupdate, md.creator);
+
+		if (graph) {
+			tracker_sparql_builder_graph_close (preupdate);
+		}
 		tracker_sparql_builder_insert_close (preupdate);
 
 		tracker_sparql_builder_predicate (metadata, "nmm:performer");
-		tracker_sparql_builder_object_iri (metadata, uri);
-		g_free (uri);
+		tracker_sparql_builder_object_iri (metadata, md.creator_uri);
 	}
 
 	if (vd.album) {
@@ -191,6 +195,10 @@ extract_vorbis (const char *uri,
 		gchar *album_disc_uri;
 
 		tracker_sparql_builder_insert_open (preupdate, NULL);
+		if (graph) {
+			tracker_sparql_builder_graph_open (preupdate, graph);
+		}
+
 		tracker_sparql_builder_subject_iri (preupdate, uri);
 		tracker_sparql_builder_predicate (preupdate, "a");
 		tracker_sparql_builder_object (preupdate, "nmm:MusicAlbum");
@@ -199,6 +207,15 @@ extract_vorbis (const char *uri,
 		 */
 		tracker_sparql_builder_predicate (preupdate, "nmm:albumTitle");
 		tracker_sparql_builder_object_unvalidated (preupdate, vd.album);
+
+		if (md.creator_uri) {
+			tracker_sparql_builder_predicate (preupdate, "nmm:albumArtist");
+			tracker_sparql_builder_object_iri (preupdate, md.creator_uri);
+		}
+
+		if (graph) {
+			tracker_sparql_builder_graph_close (preupdate);
+		}
 		tracker_sparql_builder_insert_close (preupdate);
 
 		if (vd.track_count) {
@@ -215,11 +232,17 @@ extract_vorbis (const char *uri,
 			tracker_sparql_builder_where_close (preupdate);
 
 			tracker_sparql_builder_insert_open (preupdate, NULL);
+			if (graph) {
+				tracker_sparql_builder_graph_open (preupdate, graph);
+			}
 
 			tracker_sparql_builder_subject_iri (preupdate, uri);
 			tracker_sparql_builder_predicate (preupdate, "nmm:albumTrackCount");
 			tracker_sparql_builder_object_unvalidated (preupdate, vd.track_count);
 
+			if (graph) {
+				tracker_sparql_builder_graph_close (preupdate);
+			}
 			tracker_sparql_builder_insert_close (preupdate);
 		}
 
@@ -237,11 +260,17 @@ extract_vorbis (const char *uri,
 			tracker_sparql_builder_where_close (preupdate);
 
 			tracker_sparql_builder_insert_open (preupdate, NULL);
+			if (graph) {
+				tracker_sparql_builder_graph_open (preupdate, graph);
+			}
 
 			tracker_sparql_builder_subject_iri (preupdate, uri);
 			tracker_sparql_builder_predicate (preupdate, "nmm:albumGain");
 			tracker_sparql_builder_object_double (preupdate, atof (vd.album_gain));
 
+			if (graph) {
+				tracker_sparql_builder_graph_close (preupdate);
+			}
 			tracker_sparql_builder_insert_close (preupdate);
 		}
 
@@ -259,11 +288,17 @@ extract_vorbis (const char *uri,
 			tracker_sparql_builder_where_close (preupdate);
 
 			tracker_sparql_builder_insert_open (preupdate, NULL);
+			if (graph) {
+				tracker_sparql_builder_graph_open (preupdate, graph);
+			}
 
 			tracker_sparql_builder_subject_iri (preupdate, uri);
 			tracker_sparql_builder_predicate (preupdate, "nmm:albumPeakGain");
 			tracker_sparql_builder_object_double (preupdate, atof (vd.album_peak_gain));
 
+			if (graph) {
+				tracker_sparql_builder_graph_close (preupdate);
+			}
 			tracker_sparql_builder_insert_close (preupdate);
 		}
 
@@ -294,6 +329,10 @@ extract_vorbis (const char *uri,
 		tracker_sparql_builder_where_close (preupdate);
 
 		tracker_sparql_builder_insert_open (preupdate, NULL);
+		if (graph) {
+			tracker_sparql_builder_graph_open (preupdate, graph);
+		}
+
 		tracker_sparql_builder_subject_iri (preupdate, album_disc_uri);
 		tracker_sparql_builder_predicate (preupdate, "a");
 		tracker_sparql_builder_object (preupdate, "nmm:MusicAlbumDisc");
@@ -301,6 +340,10 @@ extract_vorbis (const char *uri,
 		tracker_sparql_builder_object_int64 (preupdate, vd.disc_number ? atoi (vd.disc_number) : 1);
 		tracker_sparql_builder_predicate (preupdate, "nmm:albumDiscAlbum");
 		tracker_sparql_builder_object_iri (preupdate, uri);
+
+		if (graph) {
+			tracker_sparql_builder_graph_close (preupdate);
+		}
 		tracker_sparql_builder_insert_close (preupdate);
 
 		tracker_sparql_builder_predicate (metadata, "nmm:musicAlbumDisc");
@@ -460,16 +503,14 @@ extract_vorbis (const char *uri,
 	g_free (vd.album_artist);
 	g_free (vd.performer);
 
+	g_free (md.creator_uri);
+
 #ifdef HAVE_POSIX_FADVISE
 	posix_fadvise (fileno (f), 0, 0, POSIX_FADV_DONTNEED);
 #endif /* HAVE_POSIX_FADVISE */
 
 	/* NOTE: This calls fclose on the file */
 	ov_clear (&vf);
-}
 
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return extract_data;
+	return TRUE;
 }
