@@ -64,8 +64,8 @@ static GOptionEntry entries[] = {
 	  NULL
 	},
 	{ "list", 't', 0, G_OPTION_ARG_NONE, &list,
-	  N_("List all tags (using FILTER if specified)"),
-	  NULL,
+	  N_("List all tags (using FILTER if specified; FILTER always uses logical OR)"),
+	  N_("FILTER"),
 	},
 	{ "show-files", 's', 0, G_OPTION_ARG_NONE, &show_files,
 	  N_("Show files associated with each tag (this is only used with --list)"),
@@ -87,8 +87,7 @@ static GOptionEntry entries[] = {
 	  N_("Print version"),
 	  NULL
 	},
-	{ G_OPTION_REMAINING, 0,
-	  G_OPTION_FLAG_FILENAME,
+	{ G_OPTION_REMAINING, 0, 0,
 	  G_OPTION_ARG_FILENAME_ARRAY, &files,
 	  N_("FILE…"),
 	  N_("FILE [FILE…]")},
@@ -149,49 +148,6 @@ get_escaped_sparql_string (const gchar *str)
 	return g_string_free (sparql, FALSE);
 }
 
-static gchar *
-get_fts_string (GStrv    search_words,
-                gboolean use_or_operator,
-                gboolean for_regex,
-                gboolean use_asterisk)
-{
-	GString *fts;
-	gint i, len;
-
-	if (!search_words) {
-		return NULL;
-	}
-
-	len = g_strv_length (search_words);
-	fts = g_string_new ("");
-
-	for (i = 0; i < len; i++) {
-		g_string_append (fts, search_words[i]);
-
-		if (use_asterisk) {
-			g_string_append_c (fts, '*');
-		}
-
-		if (i < len - 1) {
-			if (for_regex) {
-				if (use_or_operator) {
-					g_string_append (fts, " || ");
-				} else {
-					g_string_append (fts, " && ");
-				}
-			} else {
-				if (use_or_operator) {
-					g_string_append (fts, " OR ");
-				} else {
-					g_string_append (fts, " ");
-				}
-			}
-		}
-	}
-
-	return g_string_free (fts, FALSE);
-}
-
 static gchar *
 get_filter_string (GStrv        files,
                    gboolean     files_are_urns,
@@ -389,12 +345,18 @@ get_all_tags (TrackerSparqlConnection *connection,
 {
 	TrackerSparqlCursor *cursor;
 	GError *error = NULL;
-	gchar *fts;
 	gchar *query;
 
-	fts = get_fts_string (files, use_or_operator, TRUE, FALSE);
+	if (files && g_strv_length (files) > 0) {
+		gchar *filter;
 
-	if (fts) {
+		/* e.g. '?label IN ("foo", "bar")' */
+		filter = g_strjoinv ("\",\"", files);
+
+		/* You might be asking, why not logical AND here, why
+		 * logical OR for FILTER, well, tags can't have
+		 * multiple labels is the simple answer.
+		 */
 		query = g_strdup_printf ("SELECT ?tag ?label nao:description(?tag) COUNT(?urns) AS urns "
 		                         "WHERE {"
 		                         "  ?tag a nao:Tag ;"
@@ -402,15 +364,16 @@ get_all_tags (TrackerSparqlConnection *connection,
 		                         "  OPTIONAL {"
 		                         "     ?urns nao:hasTag ?tag"
 		                         "  } ."
-		                         "  FILTER (?label = \"%s\")"
+		                         "  FILTER (?label IN (\"%s\"))"
 		                         "} "
 		                         "GROUP BY ?tag "
 		                         "ORDER BY ASC(?label) "
 		                         "OFFSET %d "
 		                         "LIMIT %d",
-		                         fts,
+		                         filter,
 		                         search_offset,
 		                         search_limit);
+		g_free (filter);
 	} else {
 		query = g_strdup_printf ("SELECT ?tag ?label nao:description(?tag) COUNT(?urns) AS urns "
 		                         "WHERE {"
@@ -428,8 +391,6 @@ get_all_tags (TrackerSparqlConnection *connection,
 		                         search_limit);
 	}
 
-	g_free (fts);
-
 	cursor = tracker_sparql_connection_query (connection, query, NULL, &error);
 	g_free (query);
 
